@@ -52,6 +52,13 @@ def display_word(word, args):
     elif args.compounds:
         if word.compounds:
             display_compounds(word, args.compounds)
+    elif args.phonetic:
+        if word.phonetic:
+            print(word.phonetic)
+    elif args.alternative_spellings:
+        if word.alternative_spellings:
+            for spelling in word.alternative_spellings:
+                print(spelling)
     elif args.grammar:
         display_grammar(word, args.grammar)
     elif args.export:
@@ -114,6 +121,10 @@ def parse_args():
 
     parser.add_argument('-V', '--version', action='store_true',
                         help=_('print program version'))
+    parser.add_argument('--phonetic', action='store_true',
+                        help=_('display pronunciation'))
+    parser.add_argument('--alternative-spellings', action='store_true',
+                        help=_('display alternative spellings'))
 
     return parser.parse_args()
 
