@@ -1,7 +1,7 @@
 #!/bin/sh
 
 SCRIPT_DIR="$( cd "$( dirname "$0" )" && pwd )"
-for po_file in $SCRIPT_DIR/*.po; do
+for po_file in "$SCRIPT_DIR"/*.po; do
     echo "Generating $po_file..."
     mo_dir="${po_file%%.*}/LC_MESSAGES"
     mkdir -p "$mo_dir"
